# pylint: disable=missing-module-docstring
import sys
import json

try:
    from dotenv import load_dotenv

    load_dotenv()
except ModuleNotFoundError:
    pass

import ghab


def main():
    """
    Main logic for the ghab cli.

    Parses command line args, then gets workflow billing detials, calcuates efficiencies and displays results.
    """
    args = ghab.do_argparse()

    if not args.quiet:
        # Print a startup message immediatly so users know we're up and running.
        if args.workflow:
            workflows = ", ".join(args.workflow)
            plural = "s" if len(args.workflow) > 1 else ""
        else:
            workflows = "all"
            plural = "s"
        print(f"Retrieving billing info for {workflows} workflow{plural} in GitHub repo {args.repo}", file=sys.stderr)

    workflow_billing = ghab.get_workflow_billing(
        repo=args.repo, limit=args.limit, workflows=args.workflow, github_token=args.github_token, quiet=args.quiet
    )

    efficiencies = {}
    for name, runs in workflow_billing.items():
        efficiencies[name] = {
            "avgerages": {
                "efficiency": ghab.calculate_avg_efficiency(runs),
                "billed_ms": ghab.calculate_avg_billed_ms(runs),
                "total_ms": ghab.calculate_avg_total_ms(runs),
            },
        }
        if args.show_runs:
            efficiencies[name]["runs"] = runs

    print(json.dumps(efficiencies, indent=2))


if __name__ == "__main__":
    main()
